# Pytorch EO

Deep Learning for Earth Observation applications and research.

> 🚧 This project is in early development, so bugs and breaking changes are expected until we reach a stable version.

## Installation

```
pip install pytorch-eo
```

## Examples

Learn by doing with our [examples](https://github.com/earthpulse/pytorch_eo/tree/main/examples).

## Ready to use Datasets

- [EuroSAT](https://github.com/phelber/EuroSAT)

## Documentation

Read our [docs](https://earthpulse.github.io/pytorch_eo/).

## Contributing

Read the [CONTRIBUTING](https://github.com/earthpulse/pytorch_eo/blob/main/CONTRIBUTING.md) guide.
